@@ -9,6 +9,7 @@ from .remote import (
     call,
     aiterate,
     iterate,
+    find,
     acall_raw,
 )
 from .structures.model import model
@@ -17,7 +18,7 @@ from .state.decorator import state
 try:
     from .arkitekt import RekuestNextService
 except ImportError as e:
-    pass
+    raise e
 
 
 from .structure import structure_reg
@@ -27,6 +28,7 @@ __version__ = "0.4.1"
 __all__ = [
     "acall",
     "state",
+    "find",
     "RekuestNextService",
     "call",
     "structure_reg",
