@@ -1,3 +1,6 @@
+"""This module contains the exceptions used in the Agent."""
+
+
 class AgentException(Exception):
     """
     Base class for all exceptions raised by the Agent.
@@ -16,24 +19,6 @@ class ExtensionError(AgentException):
     """
 
 
-class HookError(AgentException):
-    """
-    Base class for all exceptions raised by a hook
-    """
-
-
-class StartupHookError(HookError):
-    """
-    Raised when a startup hook fails
-    """
-
-
-class BackgroundHookError(HookError):
-    """
-    Raised when a background hook fails
-    """
-
-
 class StateRequirementsNotMet(AgentException):
     """
     Raised when the state requirements are not met
