@@ -1,6 +1,7 @@
 """Transport types for agents."""
 
 from typing import Protocol, runtime_checkable
+import typing
 from .errors import (
     DefiniteConnectionFail,
     CorrectableConnectionFail,
@@ -9,7 +10,6 @@ from .errors import (
 from rekuest_next.messages import ToAgentMessage, FromAgentMessage
 
 
-
 @runtime_checkable
 class AgentTransport(Protocol):
     """Protocol for transport."""
@@ -30,7 +30,15 @@ class AgentTransport(Protocol):
         """Set the callback for the transport."""
         ...
 
-    
+    async def __aenter__(self) -> "AgentTransport":
+        """Enter the transport context."""
+        ...
+
+    async def __aexit__(
+        self, exc_type: typing.Any, exc_value: typing.Any, traceback: typing.Any
+    ) -> None:
+        """Exit the transport context."""
+        ...
 
 
 class TransportCallbacks(Protocol):
