@@ -37,7 +37,7 @@ class GraphQLPostman(KoiledModel):
     assignations: Dict[str, Assignation] = Field(default_factory=dict)
 
     _ass_update_queues: Dict[str, asyncio.Queue[AssignationEvent]] = PrivateAttr(
-        default_factory=dict
+        default_factory=lambda: {}
     )
     _ass_update_queue: asyncio.Queue[AssignationEvent] | None = None
     _watch_assraces_task: asyncio.Task[None] | None = None
@@ -91,7 +91,12 @@ class GraphQLPostman(KoiledModel):
             ):
                 if assignation.event:
                     reference = assignation.event.reference
-                    await self._ass_update_queues[reference].put(assignation.event)
+                    if reference not in self._ass_update_queues:
+                        logger.critical(
+                            "Race connection. Maybe there was a disconnect?"
+                        )
+                    else:
+                        await self._ass_update_queues[reference].put(assignation.event)
                 if assignation.create:
                     if assignation.create.reference not in self._ass_update_queues:
                         logger.critical("RACE CONDITION EXPERIENCED")
