@@ -5,9 +5,10 @@ from koil.helpers import unkoil_task
 from koil import KoilFuture
 from pydantic import Field
 from rekuest_next.agents.hooks.background import background
+from rekuest_next.coercible_types import DependencyCoercible
 from rekuest_next.protocols import AnyFunction, BackgroundFunction, StartupFunction
 from rekuest_next.rath import RekuestNextRath
-
+from rekuest_next.agents.extensions.default import DefaultExtension
 from rekuest_next.actors.types import Actifier, Agent
 from rekuest_next.postmans.types import Postman
 from koil import unkoil
@@ -33,7 +34,6 @@ from rekuest_next.agents.hooks.startup import startup
 from rekuest_next.api.schema import (
     AssignWidgetInput,
     DefinitionInput,
-    DependencyInput,
     PortGroupInput,
     EffectInput,
     ValidatorInput,
@@ -46,8 +46,9 @@ T = TypeVar("T", bound=AnyFunction)
 class RekuestNext(Composition):
     """The main rekuest next client class"""
 
-    definition_registry: DefinitionRegistry = Field(default_factory=get_default_definition_registry)
-    structure_registry: StructureRegistry = Field(default_factory=get_default_structure_registry)
+    structure_registry: StructureRegistry = Field(
+        default_factory=get_default_structure_registry
+    )
     rath: RekuestNextRath
     agent: Agent
     postman: Postman
@@ -59,7 +60,7 @@ class RekuestNext(Composition):
         interface: Optional[str] = None,
         stateful: bool = False,
         widgets: Optional[Dict[str, AssignWidgetInput]] = None,
-        dependencies: Optional[List[DependencyInput]] = None,
+        dependencies: Optional[List[DependencyCoercible]] = None,
         interfaces: Optional[List[str]] = None,
         collections: Optional[List[str]] = None,
         port_groups: Optional[List[PortGroupInput]] = None,
@@ -105,10 +106,16 @@ class RekuestNext(Composition):
             function: A decorator that registers the given function or actor.
         """
 
+        default_extension = self.agent.extension_registry.get("default")
+        assert default_extension is not None, "Default extension not found"
+        assert isinstance(default_extension, DefaultExtension), (
+            "Default is not a DefaultExtension"
+        )
+
         return register_func(
             function,
-            self.structure_registry,
-            self.definition_registry,
+            structure_registry=structure_registry or self.structure_registry,
+            definition_registry=default_extension.definition_registry,
             actifier=actifier,
             interface=interface,
             stateful=stateful,
@@ -128,21 +135,29 @@ class RekuestNext(Composition):
             sync=sync,
         )
 
-    def register_startup(self, function: StartupFunction, name: str | None = None) -> None:
+    def register_startup(
+        self, function: StartupFunction, name: str | None = None
+    ) -> None:
         """Register a startup function that will be called when the agent starts.
 
         Args:
             function (AnyFunction): The startup function to register.
         """
-        startup(function, name=name or function.__name__, registry=self.agent.hook_registry)
+        startup(
+            function, name=name or function.__name__, registry=self.agent.hook_registry
+        )
 
-    def register_background(self, function: BackgroundFunction, name: str | None = None) -> None:
+    def register_background(
+        self, function: BackgroundFunction, name: str | None = None
+    ) -> None:
         """Register a background function that will be run in the background.
 
         Args:
             function (BackgroundFunction): The background function to register.
         """
-        background(function, name=name or function.__name__, registry=self.agent.hook_registry)
+        background(
+            function, name=name or function.__name__, registry=self.agent.hook_registry
+        )
 
     def run(self, instance_id: str | None = None) -> None:
         """
