@@ -19,21 +19,17 @@ GLOBAL_STATE_REGISTRY = None
 class StateRegistry(KoiledModel):
     """The state registry is used to register the states of the actors."""
 
-    state_schemas: Dict[str, StateSchemaInput] = Field(
-        default_factory=dict, exclude=True
-    )
-    registry_schemas: Dict[str, StructureRegistry] = Field(
-        default_factory=dict, exclude=True
-    )
-    interface_classes: Dict[str, AnyState] = Field(
-        default_factory=dict, exclude=True
-    )
-    classes_interfaces: Dict[Type[AnyState], str] = Field(
-        default_factory=dict, exclude=True
-    )
+    state_schemas: Dict[str, StateSchemaInput] = Field(default_factory=dict, exclude=True)
+    registry_schemas: Dict[str, StructureRegistry] = Field(default_factory=dict, exclude=True)
+    interface_classes: Dict[str, AnyState] = Field(default_factory=dict, exclude=True)
+    classes_interfaces: Dict[Type[AnyState], str] = Field(default_factory=lambda: {}, exclude=True)
 
     def register_at_interface(
-        self, interface: str, cls: Type[AnyState],  state_schema: StateSchemaInput, registry: StructureRegistry
+        self,
+        interface: str,
+        cls: Type[AnyState],
+        state_schema: StateSchemaInput,
+        registry: StructureRegistry,
     ) -> None:
         """Register a state schema at a name."""
         self.state_schemas[interface] = state_schema
@@ -45,18 +41,16 @@ class StateRegistry(KoiledModel):
         """Get the schema for a name."""
         assert interface in self.state_schemas, "No definition for interface"
         return self.state_schemas[interface]
-    
+
     def get_registry_for_interface(self, interface: str) -> StructureRegistry:
         """Get the registry for a name."""
         assert interface in self.registry_schemas, "No definition for interface"
         return self.registry_schemas[interface]
-    
+
     def get_interface_for_class(self, cls: Type[AnyState]) -> str:
         """Get the interface for a class."""
         assert cls in self.classes_interfaces, "No definition for class"
         return self.classes_interfaces[cls]
-    
-    
 
     async def __aenter__(self) -> "StateRegistry":
         """Enter the state registry context manager."""
@@ -82,9 +76,7 @@ class StateRegistry(KoiledModel):
 
     def hash(self) -> str:
         """A hash of the state registry, used to check if the state registry has changed"""
-        return hashlib.sha256(
-            json.dumps(self.dump(), sort_keys=True).encode()
-        ).hexdigest()
+        return hashlib.sha256(json.dumps(self.dump(), sort_keys=True).encode()).hexdigest()
 
 
 def get_default_state_registry() -> "StateRegistry":
