@@ -74,13 +74,17 @@ class StructureRegistry(BaseModel):
     identifier_structure_map: Dict[str, FullFilledStructure] = Field(
         default_factory=dict, exclude=True
     )
-    identifier_enum_map: Dict[str, FullFilledEnum] = Field(default_factory=dict, exclude=True)
+    identifier_enum_map: Dict[str, FullFilledEnum] = Field(
+        default_factory=dict, exclude=True
+    )
     identifier_memory_structure_map: Dict[str, FullFilledMemoryStructure] = Field(
         default_factory=dict, exclude=True
     )
-    identifier_model_map: Dict[str, FullFilledModel] = Field(default_factory=dict, exclude=True)
-    cls_fullfilled_type_map: Dict[Type[Any], FullFilledType] = Field(
+    identifier_model_map: Dict[str, FullFilledModel] = Field(
         default_factory=dict, exclude=True
+    )
+    cls_fullfilled_type_map: Dict[Type[Any], FullFilledType] = Field(
+        default_factory=lambda: {}, exclude=True
     )  # Map from class to fullfilled type
 
     model_config = ConfigDict(arbitrary_types_allowed=True)
@@ -97,7 +101,9 @@ class StructureRegistry(BaseModel):
         """Get the fullfilled model for a given identifier."""
         return self.identifier_model_map[identifier]
 
-    def get_fullfilled_memory_structure(self, identifier: str) -> FullFilledMemoryStructure:
+    def get_fullfilled_memory_structure(
+        self, identifier: str
+    ) -> FullFilledMemoryStructure:
         """Get the fullfilled memory structure for a given identifier."""
         return self.identifier_memory_structure_map[identifier]
 
@@ -153,7 +159,9 @@ class StructureRegistry(BaseModel):
         try:
             return self.cls_fullfilled_type_map[cls].identifier
         except KeyError as e:
-            raise StructureRegistryError(f"Identifier for {cls} is not registered") from e
+            raise StructureRegistryError(
+                f"Identifier for {cls} is not registered"
+            ) from e
 
     def register_as_model(
         self,
@@ -290,7 +298,9 @@ class StructureRegistry(BaseModel):
             return
 
         if isinstance(fullfilled_type, FullFilledMemoryStructure):
-            self.identifier_memory_structure_map[fullfilled_type.identifier] = fullfilled_type
+            self.identifier_memory_structure_map[fullfilled_type.identifier] = (
+                fullfilled_type
+            )
             return
 
         if isinstance(fullfilled_type, FullFilledStructure):  # type: ignore
@@ -336,7 +346,7 @@ class StructureRegistry(BaseModel):
                 default=None,
                 nullable=nullable,
                 effects=tuple(effects or []),
-                description=fullfilled_type.description,
+                description=description or fullfilled_type.description,
                 validators=tuple(validators or []),
             )
 
@@ -349,10 +359,12 @@ class StructureRegistry(BaseModel):
                 choices=tuple(fullfilled_type.choices),
                 key=key,
                 label=label,
-                default=fullfilled_type.convert_default(default) if default is not None else None,
+                default=fullfilled_type.convert_default(default)
+                if default is not None
+                else None,
                 nullable=nullable,
                 effects=tuple(effects or []),
-                description=fullfilled_type.description,
+                description=description or fullfilled_type.description,
                 validators=tuple(validators or []),
             )
 
@@ -367,7 +379,7 @@ class StructureRegistry(BaseModel):
                 default=None,
                 nullable=nullable,
                 effects=tuple(effects or []),
-                description=fullfilled_type.description,
+                description=description or fullfilled_type.description,
                 validators=tuple(validators or []),
             )
 
@@ -382,7 +394,7 @@ class StructureRegistry(BaseModel):
                 default=None,
                 nullable=nullable,
                 effects=tuple(effects or []),
-                description=fullfilled_type.description,
+                description=description or fullfilled_type.description,
                 validators=tuple(validators or []),
             )
 
