@@ -467,7 +467,12 @@ async def aexpand_return(
                 f"Expected value to be a string or int, but got {type(value)}"
             )
 
-        fstruc = structure_registry.get_fullfilled_structure(port.identifier)
+        try:
+            fstruc = structure_registry.get_fullfilled_structure(port.identifier)
+        except KeyError as e:
+            raise PortExpandingError(
+                f"Structure {port.identifier} not found. Was it ever registered?"
+            ) from e
 
         try:
             return await fstruc.aexpand(ID.validate(value))
@@ -526,7 +531,7 @@ async def aexpand_returns(
                 )
             except Exception as e:
                 raise ExpandingError(
-                    f"Couldn't expand return {returns[port.key]} with port {port}"
+                    f"Couldn't expand the reutrn value `{returns[port.key]}` for port {port.key}"
                 ) from e
 
         expanded_returns.append(expanded_return)
