@@ -9,9 +9,14 @@ from rekuest_next.api.schema import (
     ReturnWidgetKind,
     ValidatorFunction,
     ValidatorInput,
+    EffectInput,
+    EffectKind,
 )
+from rekuest_next.structures.types import JSONSerializable
+from rekuest_next.definition.utils import DefaultAddin, DescriptionAddin
 from rekuest_next.scalars import SearchQuery
-from typing import List
+from typing import Any, List
+from rekuest_next.scalars import ValidatorFunctionCoercible
 
 
 def SliderWidget(
@@ -146,9 +151,7 @@ def ChoiceWidget(choices: List[ChoiceInput]) -> AssignWidgetInput:
     return AssignWidgetInput(kind=AssignWidgetKind.CHOICE, choices=tuple(choices))
 
 
-def withChoices(
-    *choices: ChoiceInput,
-) -> AssignWidgetInput:
+def withChoices(*choices: ChoiceInput | JSONSerializable) -> AssignWidgetInput:
     """A decorator to add choices to a widget.
 
     Args:
@@ -157,7 +160,17 @@ def withChoices(
     Returns:
         AssignWidgetInput: The widget input
     """
-    return AssignWidgetInput(kind=AssignWidgetKind.CHOICE, choices=tuple(choices))
+    if not choices:
+        raise ValueError("You need to provide at least one choice")
+
+    parsed_choices: list[ChoiceInput] = []
+
+    for choice in choices:
+        if not isinstance(choice, ChoiceInput):
+            choice = ChoiceInput(value=choice, label=str(choice))
+        parsed_choices.append(choice)
+
+    return AssignWidgetInput(kind=AssignWidgetKind.CHOICE, choices=tuple(parsed_choices))
 
 
 def withValidator(
@@ -180,3 +193,52 @@ def withValidator(
         errorMessage=errorMessage,
         dependencies=tuple(dependencies) if dependencies else None,
     )
+
+
+def withDescription(description: str) -> DescriptionAddin:
+    """A decorator to add a description to a widget.
+
+    Args:
+        description (str): The description to add
+
+    Returns:
+        DescriptionAddin: The description addin
+    """
+    return DescriptionAddin(value=description)
+
+
+def withDefault(value: Any) -> DefaultAddin:
+    """A decorator to add a default value to a widget.
+
+    Args:
+        value (Any): The default value
+
+    Returns:
+        DefaultAddin: The default addin
+    """
+    return DefaultAddin(value=value)
+
+
+def withEffect(
+    kind: EffectKind,
+    function: ValidatorFunctionCoercible,
+    dependencies: List[str] | None = None,
+    message: str | None = None,
+) -> EffectInput:
+    """A decorator to add an effect to a widget.
+
+    Args:
+        effect (str): The effect to run
+        function (ValidatorFunctionCoercible): The function that checks if the effect should run
+        dependencies (List[str], optional): The dependencies of the effect. Defaults to None.
+        message (str, optional): The message to show if it is a MessageEffect. Defaults to None.
+
+    Returns:
+        AssignWidgetInput: The widget input
+    """
+    return EffectInput(
+        function=ValidatorFunction.validate(function),
+        kind=kind,
+        dependencies=tuple(dependencies) if dependencies else None,
+        message=message,
+    )
